# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.26.4](https://github.com/conda/rattler/compare/rattler_shell-v0.26.3...rattler_shell-v0.26.4) - 2026-03-18

### Other

- update Cargo.toml dependencies

## [0.26.3](https://github.com/conda/rattler/compare/rattler_shell-v0.26.2...rattler_shell-v0.26.3) - 2026-03-16

### Other

- updated the following local packages: rattler_conda_types

## [0.26.2](https://github.com/conda/rattler/compare/rattler_shell-v0.26.1...rattler_shell-v0.26.2) - 2026-02-25

### Other

- updated the following local packages: rattler_conda_types

## [0.26.1](https://github.com/conda/rattler/compare/rattler_shell-v0.26.0...rattler_shell-v0.26.1) - 2026-02-20

### Other

- updated the following local packages: rattler_conda_types

## [0.26.0](https://github.com/conda/rattler/compare/rattler_shell-v0.25.19...rattler_shell-v0.26.0) - 2026-02-19

### Other

- Typo and clippy fixes ([#2047](https://github.com/conda/rattler/pull/2047))
- [**breaking**] remove support for JLAP ([#2038](https://github.com/conda/rattler/pull/2038))

## [0.25.19](https://github.com/conda/rattler/compare/rattler_shell-v0.25.18...rattler_shell-v0.25.19) - 2026-02-04

### Fixed

- Ignore CONDA_SHLVL in tests ([#2029](https://github.com/conda/rattler/pull/2029))

## [0.25.18](https://github.com/conda/rattler/compare/rattler_shell-v0.25.17...rattler_shell-v0.25.18) - 2026-01-22

### Other

- updated the following local packages: rattler_conda_types

## [0.25.17](https://github.com/baszalmstra/rattler/compare/rattler_shell-v0.25.16...rattler_shell-v0.25.17) - 2026-01-22

### Fixed

- changelog

## [0.25.16](https://github.com/conda/rattler/compare/rattler_shell-v0.25.15...rattler_shell-v0.25.16) - 2026-01-22

### Other

- updated the following local packages: rattler_conda_types, rattler_pty

## [0.25.15](https://github.com/conda/rattler/compare/rattler_shell-v0.25.14...rattler_shell-v0.25.15) - 2025-12-18

### Fixed

- always emit depends in index.json ([#1932](https://github.com/conda/rattler/pull/1932))

### Other

- update README.md with new banner image ([#1926](https://github.com/conda/rattler/pull/1926))

## [0.25.14](https://github.com/conda/rattler/compare/rattler_shell-v0.25.13...rattler_shell-v0.25.14) - 2025-12-08

### Other

- bump crates ([#1902](https://github.com/conda/rattler/pull/1902))

## [0.25.13](https://github.com/conda/rattler/compare/rattler_shell-v0.25.12...rattler_shell-v0.25.13) - 2025-11-27

### Other

- updated the following local packages: rattler_conda_types

## [0.25.12](https://github.com/conda/rattler/compare/rattler_shell-v0.25.11...rattler_shell-v0.25.12) - 2025-11-25

### Other

- updated the following local packages: rattler_conda_types

## [0.25.11](https://github.com/conda/rattler/compare/rattler_shell-v0.25.10...rattler_shell-v0.25.11) - 2025-11-22

### Other

- updated the following local packages: rattler_conda_types

## [0.25.10](https://github.com/conda/rattler/compare/rattler_shell-v0.25.9...rattler_shell-v0.25.10) - 2025-11-20

### Other

- updated the following local packages: rattler_conda_types

## [0.25.9](https://github.com/conda/rattler/compare/rattler_shell-v0.25.8...rattler_shell-v0.25.9) - 2025-11-19

### Other

- updated the following local packages: rattler_conda_types

## [0.25.8](https://github.com/conda/rattler/compare/rattler_shell-v0.25.7...rattler_shell-v0.25.8) - 2025-11-13

### Other

- updated the following local packages: rattler_conda_types

## [0.25.7](https://github.com/conda/rattler/compare/rattler_shell-v0.25.6...rattler_shell-v0.25.7) - 2025-10-28

### Other

- updated the following local packages: rattler_conda_types

## [0.25.6](https://github.com/conda/rattler/compare/rattler_shell-v0.25.5...rattler_shell-v0.25.6) - 2025-10-25

### Other

- Improve performance of bash shell activation on Windows ([#1758](https://github.com/conda/rattler/pull/1758))

## [0.25.5](https://github.com/conda/rattler/compare/rattler_shell-v0.25.4...rattler_shell-v0.25.5) - 2025-10-18

### Other

- updated the following local packages: rattler_conda_types

## [0.25.4](https://github.com/conda/rattler/compare/rattler_shell-v0.25.3...rattler_shell-v0.25.4) - 2025-10-17

### Other

- updated the following local packages: rattler_conda_types, rattler_pty

## [0.25.3](https://github.com/conda/rattler/compare/rattler_shell-v0.25.2...rattler_shell-v0.25.3) - 2025-10-14

### Other

- updated the following local packages: rattler_conda_types

## [0.25.2](https://github.com/conda/rattler/compare/rattler_shell-v0.25.1...rattler_shell-v0.25.2) - 2025-10-03

### Other

- updated the following local packages: rattler_conda_types

## [0.25.1](https://github.com/conda/rattler/compare/rattler_shell-v0.25.0...rattler_shell-v0.25.1) - 2025-09-30

### Other

- updated the following local packages: rattler_conda_types

## [0.25.0](https://github.com/conda/rattler/compare/rattler_shell-v0.24.11...rattler_shell-v0.25.0) - 2025-09-12

### Added

- add support for post-activation environment variables in Activator ([#1673](https://github.com/conda/rattler/pull/1673))

## [0.24.11](https://github.com/conda/rattler/compare/rattler_shell-v0.24.10...rattler_shell-v0.24.11) - 2025-09-05

### Other

- updated the following local packages: rattler_conda_types

## [0.24.10](https://github.com/conda/rattler/compare/rattler_shell-v0.24.9...rattler_shell-v0.24.10) - 2025-09-02

### Other

- updated the following local packages: rattler_conda_types

## [0.24.9](https://github.com/conda/rattler/compare/rattler_shell-v0.24.8...rattler_shell-v0.24.9) - 2025-08-15

### Other

- updated the following local packages: rattler_conda_types

## [0.24.8](https://github.com/conda/rattler/compare/rattler_shell-v0.24.7...rattler_shell-v0.24.8) - 2025-08-12

### Other

- updated the following local packages: rattler_conda_types

## [0.24.7](https://github.com/conda/rattler/compare/rattler_shell-v0.24.6...rattler_shell-v0.24.7) - 2025-07-24

### Fixed

- allow variable expansion ([#1552](https://github.com/conda/rattler/pull/1552))

## [0.24.6](https://github.com/conda/rattler/compare/rattler_shell-v0.24.5...rattler_shell-v0.24.6) - 2025-07-23

### Other

- update Cargo.toml dependencies

## [0.24.5](https://github.com/conda/rattler/compare/rattler_shell-v0.24.4...rattler_shell-v0.24.5) - 2025-07-21

### Other

- bump rust 1.88.0 ([#1536](https://github.com/conda/rattler/pull/1536))

## [0.24.4](https://github.com/conda/rattler/compare/rattler_shell-v0.24.3...rattler_shell-v0.24.4) - 2025-07-14

### Other

- updated the following local packages: rattler_conda_types

## [0.24.3](https://github.com/conda/rattler/compare/rattler_shell-v0.24.2...rattler_shell-v0.24.3) - 2025-07-09

### Other

- updated the following local packages: rattler_conda_types

## [0.24.2](https://github.com/conda/rattler/compare/rattler_shell-v0.24.1...rattler_shell-v0.24.2) - 2025-07-01

### Fixed

- *(ci)* run pre-commit-run for all files ([#1481](https://github.com/conda/rattler/pull/1481))

## [0.24.1](https://github.com/conda/rattler/compare/rattler_shell-v0.24.0...rattler_shell-v0.24.1) - 2025-06-26

### Other

- updated the following local packages: rattler_conda_types, rattler_pty

## [0.24.0](https://github.com/conda/rattler/compare/rattler_shell-v0.23.4...rattler_shell-v0.24.0) - 2025-06-25

### Added

- Add `deactivation()` method to Activator ([#1278](https://github.com/conda/rattler/pull/1278))

## [0.23.4](https://github.com/conda/rattler/compare/rattler_shell-v0.23.3...rattler_shell-v0.23.4) - 2025-06-24

### Fixed

- simplify validate env vars ([#1465](https://github.com/conda/rattler/pull/1465))

## [0.23.3](https://github.com/conda/rattler/compare/rattler_shell-v0.23.2...rattler_shell-v0.23.3) - 2025-06-23

### Fixed

- quote values in bash activation with shlex ([#1392](https://github.com/conda/rattler/pull/1392))

### Other

- update npm name ([#1368](https://github.com/conda/rattler/pull/1368))
- update readme ([#1364](https://github.com/conda/rattler/pull/1364))

## [0.23.2](https://github.com/conda/rattler/compare/rattler_shell-v0.23.1...rattler_shell-v0.23.2) - 2025-05-23

### Other

- updated the following local packages: rattler_conda_types

## [0.23.1](https://github.com/conda/rattler/compare/rattler_shell-v0.23.0...rattler_shell-v0.23.1) - 2025-05-16

### Other

- update Cargo.toml dependencies

## [0.23.0](https://github.com/conda/rattler/compare/rattler_shell-v0.22.26...rattler_shell-v0.23.0) - 2025-05-03

### Fixed

- sanitize env vars ([#1222](https://github.com/conda/rattler/pull/1222))

### Other

- lock workspace member dependencies ([#1279](https://github.com/conda/rattler/pull/1279))

## [0.22.26](https://github.com/conda/rattler/compare/rattler_shell-v0.22.25...rattler_shell-v0.22.26) - 2025-04-10

### Added

- Add start_unix_shell in Activator (2/n) ([#1180](https://github.com/conda/rattler/pull/1180))

## [0.22.25](https://github.com/conda/rattler/compare/rattler_shell-v0.22.24...rattler_shell-v0.22.25) - 2025-04-04

### Other

- update Cargo.toml dependencies

## [0.22.24](https://github.com/conda/rattler/compare/rattler_shell-v0.22.23...rattler_shell-v0.22.24) - 2025-03-14

### Other

- updated the following local packages: rattler_conda_types

## [0.22.23](https://github.com/conda/rattler/compare/rattler_shell-v0.22.22...rattler_shell-v0.22.23) - 2025-03-10

### Other

- release ([#1137](https://github.com/conda/rattler/pull/1137))

## [0.22.22](https://github.com/conda/rattler/compare/rattler_shell-v0.22.21...rattler_shell-v0.22.22) - 2025-02-28

### Other

- update Cargo.toml dependencies

## [0.22.21](https://github.com/conda/rattler/compare/rattler_shell-v0.22.20...rattler_shell-v0.22.21) - 2025-02-27

### Added

- implement shell completion helpers (#1075)

## [0.22.20](https://github.com/conda/rattler/compare/rattler_shell-v0.22.19...rattler_shell-v0.22.20) - 2025-02-25

### Other

- update Cargo.toml dependencies

## [0.22.19](https://github.com/conda/rattler/compare/rattler_shell-v0.22.18...rattler_shell-v0.22.19) - 2025-02-18

### Other

- update dependencies (#1069)

## [0.22.18](https://github.com/conda/rattler/compare/rattler_shell-v0.22.17...rattler_shell-v0.22.18) - 2025-02-06

### Other

- bump rust 1.84.1 (#1053)

## [0.22.17](https://github.com/conda/rattler/compare/rattler_shell-v0.22.16...rattler_shell-v0.22.17) - 2025-02-03

### Other

- updated the following local packages: rattler_conda_types

## [0.22.16](https://github.com/conda/rattler/compare/rattler_shell-v0.22.15...rattler_shell-v0.22.16) - 2025-01-23

### Other

- updated the following local packages: rattler_conda_types

## [0.22.15](https://github.com/conda/rattler/compare/rattler_shell-v0.22.14...rattler_shell-v0.22.15) - 2025-01-09

### Other

- updated the following local packages: rattler_conda_types

## [0.22.14](https://github.com/conda/rattler/compare/rattler_shell-v0.22.13...rattler_shell-v0.22.14) - 2025-01-09

### Other

- updated the following local packages: rattler_conda_types

## [0.22.13](https://github.com/conda/rattler/compare/rattler_shell-v0.22.12...rattler_shell-v0.22.13) - 2025-01-08

### Other

- updated the following local packages: rattler_conda_types

## [0.22.12](https://github.com/conda/rattler/compare/rattler_shell-v0.22.11...rattler_shell-v0.22.12) - 2024-12-20

### Other

- updated the following local packages: rattler_conda_types

## [0.22.11](https://github.com/conda/rattler/compare/rattler_shell-v0.22.10...rattler_shell-v0.22.11) - 2024-12-17

### Other

- update Cargo.toml dependencies

## [0.22.10](https://github.com/conda/rattler/compare/rattler_shell-v0.22.9...rattler_shell-v0.22.10) - 2024-12-13

### Other

- updated the following local packages: rattler_conda_types

## [0.22.9](https://github.com/conda/rattler/compare/rattler_shell-v0.22.8...rattler_shell-v0.22.9) - 2024-12-12

### Other
- updated the following local packages: rattler_conda_types

## [0.22.8](https://github.com/conda/rattler/compare/rattler_shell-v0.22.7...rattler_shell-v0.22.8) - 2024-11-30

### Other

- updated the following local packages: rattler_conda_types

## [0.22.7](https://github.com/conda/rattler/compare/rattler_shell-v0.22.6...rattler_shell-v0.22.7) - 2024-11-18

### Other

- updated the following local packages: rattler_conda_types

## [0.22.6](https://github.com/conda/rattler/compare/rattler_shell-v0.22.5...rattler_shell-v0.22.6) - 2024-11-14

### Other

- updated the following local packages: rattler_conda_types

## [0.22.5](https://github.com/conda/rattler/compare/rattler_shell-v0.22.4...rattler_shell-v0.22.5) - 2024-11-04

### Other

- update all versions of packages ([#886](https://github.com/conda/rattler/pull/886))
- release ([#903](https://github.com/conda/rattler/pull/903))

## [0.22.4](https://github.com/conda/rattler/compare/rattler_shell-v0.22.3...rattler_shell-v0.22.4) - 2024-10-07

### Other

- updated the following local packages: rattler_conda_types

## [0.22.3](https://github.com/conda/rattler/compare/rattler_shell-v0.22.2...rattler_shell-v0.22.3) - 2024-10-03

### Other

- updated the following local packages: rattler_conda_types

## [0.22.2](https://github.com/conda/rattler/compare/rattler_shell-v0.22.1...rattler_shell-v0.22.2) - 2024-09-23

### Other

- updated the following local packages: rattler_conda_types

## [0.22.1](https://github.com/conda/rattler/compare/rattler_shell-v0.22.0...rattler_shell-v0.22.1) - 2024-09-09

### Other

- updated the following local packages: rattler_conda_types

## [0.22.0](https://github.com/conda/rattler/compare/rattler_shell-v0.21.8...rattler_shell-v0.22.0) - 2024-09-05

### Fixed
- remaining typos ([#854](https://github.com/conda/rattler/pull/854))
- typos ([#849](https://github.com/conda/rattler/pull/849))

## [0.21.8](https://github.com/conda/rattler/compare/rattler_shell-v0.21.7...rattler_shell-v0.21.8) - 2024-09-03

### Other
- make PackageCache multi-process safe ([#837](https://github.com/conda/rattler/pull/837))

## [0.21.7](https://github.com/conda/rattler/compare/rattler_shell-v0.21.6...rattler_shell-v0.21.7) - 2024-09-02

### Other
- updated the following local packages: rattler_conda_types

## [0.21.6](https://github.com/conda/rattler/compare/rattler_shell-v0.21.5...rattler_shell-v0.21.6) - 2024-08-15

### Fixed
- move more links to the conda org from conda-incubator ([#816](https://github.com/conda/rattler/pull/816))

### Other
- change links from conda-incubator to conda ([#813](https://github.com/conda/rattler/pull/813))
- update banner ([#808](https://github.com/conda/rattler/pull/808))

## [0.21.5](https://github.com/baszalmstra/rattler/compare/rattler_shell-v0.21.4...rattler_shell-v0.21.5) - 2024-08-06

### Other
- updated the following local packages: rattler_conda_types

## [0.21.4](https://github.com/baszalmstra/rattler/compare/rattler_shell-v0.21.3...rattler_shell-v0.21.4) - 2024-08-02

### Other
- updated the following local packages: rattler_conda_types

## [0.21.3](https://github.com/conda/rattler/compare/rattler_shell-v0.21.2...rattler_shell-v0.21.3) - 2024-07-23

### Other
- updated the following local packages: rattler_conda_types

## [0.21.2](https://github.com/conda/rattler/compare/rattler_shell-v0.21.1...rattler_shell-v0.21.2) - 2024-07-23

### Other
- updated the following local packages: rattler_conda_types

## [0.21.1](https://github.com/conda/rattler/compare/rattler_shell-v0.21.0...rattler_shell-v0.21.1) - 2024-07-15

### Other
- update Cargo.toml dependencies

## [0.21.0](https://github.com/conda/rattler/compare/rattler_shell-v0.20.9...rattler_shell-v0.21.0) - 2024-07-08

### Added
- add direct url repodata building ([#725](https://github.com/conda/rattler/pull/725))
- allow passing custom environment to run_activation ([#743](https://github.com/conda/rattler/pull/743))

## [0.20.9](https://github.com/conda/rattler/compare/rattler_shell-v0.20.8...rattler_shell-v0.20.9) - 2024-06-06

### Other
- make `prefix_paths_entries` pub ([#729](https://github.com/conda/rattler/pull/729))

## [0.20.8](https://github.com/baszalmstra/rattler/compare/rattler_shell-v0.20.7...rattler_shell-v0.20.8) - 2024-06-04

### Fixed
- nushell environment variable quoting ([#719](https://github.com/baszalmstra/rattler/pull/719))

## [0.20.7](https://github.com/conda/rattler/compare/rattler_shell-v0.20.6...rattler_shell-v0.20.7) - 2024-06-03

### Other
- updated the following local packages: rattler_conda_types

## [0.20.6](https://github.com/conda/rattler/compare/rattler_shell-v0.20.5...rattler_shell-v0.20.6) - 2024-05-28

### Other
- updated the following local packages: rattler_conda_types

## [0.20.5](https://github.com/conda/rattler/compare/rattler_shell-v0.20.4...rattler_shell-v0.20.5) - 2024-05-27

### Other
- updated the following local packages: rattler_conda_types

## [0.20.4](https://github.com/conda/rattler/compare/rattler_shell-v0.20.3...rattler_shell-v0.20.4) - 2024-05-14

### Added
- exclude repodata records based on timestamp ([#654](https://github.com/conda/rattler/pull/654))

## [0.20.3](https://github.com/conda/rattler/compare/rattler_shell-v0.20.2...rattler_shell-v0.20.3) - 2024-05-13

### Other
- updated the following local packages: rattler_conda_types

## [0.20.2](https://github.com/conda/rattler/compare/rattler_shell-v0.20.1...rattler_shell-v0.20.2) - 2024-05-06

### Other
- updated the following local packages: rattler_conda_types

## [0.20.1](https://github.com/conda/rattler/compare/rattler_shell-v0.20.0...rattler_shell-v0.20.1) - 2024-04-25

### Fixed
- compare `UrlOrPath` ([#618](https://github.com/conda/rattler/pull/618))

## [0.20.0](https://github.com/conda/rattler/compare/rattler_shell-v0.19.6...rattler_shell-v0.20.0) - 2024-04-19

### Fixed
- unicode activation issues on windows ([#604](https://github.com/conda/rattler/pull/604))

## [0.19.6](https://github.com/baszalmstra/rattler/compare/rattler_shell-v0.19.5...rattler_shell-v0.19.6) - 2024-04-05

### Fixed
- run post-link scripts ([#574](https://github.com/baszalmstra/rattler/pull/574))

## [0.19.5](https://github.com/conda/rattler/compare/rattler_shell-v0.19.4...rattler_shell-v0.19.5) - 2024-03-30

### Other
- updated the following local packages: rattler_conda_types

## [0.19.4](https://github.com/conda/rattler/compare/rattler_shell-v0.19.3...rattler_shell-v0.19.4) - 2024-03-21

### Other
- updated the following local packages: rattler_conda_types

## [0.19.3](https://github.com/conda/rattler/compare/rattler_shell-v0.19.2...rattler_shell-v0.19.3) - 2024-03-14

### Other
- add pixi badge ([#563](https://github.com/conda/rattler/pull/563))

## [0.19.2](https://github.com/conda/rattler/compare/rattler_shell-v0.19.1...rattler_shell-v0.19.2) - 2024-03-08

### Fixed
- better handle utf8 paths in CmdExe and Powershell ([#561](https://github.com/conda/rattler/pull/561))

## [0.19.1](https://github.com/conda/rattler/compare/rattler_shell-v0.19.0...rattler_shell-v0.19.1) - 2024-03-06

### Fixed
- dont use workspace dependencies for local crates ([#546](https://github.com/conda/rattler/pull/546))

### Other
- every crate should have its own version ([#557](https://github.com/conda/rattler/pull/557))

## [0.19.0](https://github.com/baszalmstra/rattler/compare/rattler_shell-v0.18.0...rattler_shell-v0.19.0) - 2024-02-26
